<?php
/**
 * tr_salon_lite functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package tr_salon_lite
 */

if ( ! function_exists( 'tr_salon_lite_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function tr_salon_lite_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on tr-salon, use a find and replace
		 * to change 'tr-salon-lite' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'tr-salon-lite', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );
		/*
		 * Add Image Size
		 *
		 * @link https://developer.wordpress.org/reference/functions/add_image_size/
		 */
		 add_image_size('tr-salon-lite-posts-thumbnail-size' , 1200 , 500 , true);
		 add_image_size('tr-salon-lite-posts-details-thumbnail-size' , 1200 , 600 , true);
		 

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus( array(
			'headermenu' => esc_html__( 'Primary', 'tr-salon-lite' ),
		) );
		register_nav_menus( array(
			'footermenu' => esc_html__( 'Footer Menu', 'tr-salon-lite' ),
		) );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		// Set up the WordPress core custom background feature.
		add_theme_support( 'custom-background', apply_filters( 'tr_salon_lite_custom_background_args', array(
			'default-color' => 'ffffff',
			'default-image' => '',
		) ) );

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support( 'custom-logo', array(
			'height'      => 250,
			'width'       => 250,
			'flex-width'  => true,
			'flex-height' => true,
		) );

		/**
		 * Registers an editor stylesheet for the theme.
		 */
		add_editor_style('css/editor-style.css' );
		

	}
endif;
add_action( 'after_setup_theme', 'tr_salon_lite_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function tr_salon_lite_content_width() {
	// This variable is intended to be overruled from themes.
	// Open WPCS issue: {@link https://github.com/WordPress-Coding-Standards/WordPress-Coding-Standards/issues/1043}.
	// phpcs:ignore WordPress.NamingConventions.PrefixAllGlobals.NonPrefixedVariableFound
	$GLOBALS['content_width'] = apply_filters( 'tr_salon_lite_content_width', 640 );
}
add_action( 'after_setup_theme', 'tr_salon_lite_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function tr_salon_lite_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'tr-salon-lite' ),
		'id'            => 'sidebar-1',
		'description'   => esc_html__( 'Add widgets here.', 'tr-salon-lite' ),
		'before_widget' => '<div id="%1$s" class="widget %2$s"><div class="sidebar-posts">',
		'after_widget'  => '</div></div>',
		'before_title'  => '<h3 class="sidebar-post-title">',
		'after_title'   => '</h3>',
	) );
	register_sidebar( array(
		'name'          => esc_html__( 'Footer 1', 'tr-salon-lite' ),
		'id'            => 'footer-1',
		'description'   => esc_html__( 'Add footer widgets here.', 'tr-salon-lite' ),
		'before_widget' => '<div id="%1$s" class="widget %2$s"><div class="footer-content">',
		'after_widget'  => '</div></div>',
		'before_title'  => '<h3>',
		'after_title'   => '</h3>',
	) );
	register_sidebar( array(
		'name'          => esc_html__( 'Footer 2', 'tr-salon-lite' ),
		'id'            => 'footer-2',
		'description'   => esc_html__( 'Add footer widgets here.', 'tr-salon-lite' ),
		'before_widget' => '<div id="%1$s" class="widget %2$s"><div class="footer-content">',
		'after_widget'  => '</div></div>',
		'before_title'  => '<h3>',
		'after_title'   => '</h3>',
	) );
	register_sidebar( array(
		'name'          => esc_html__( 'Footer 3', 'tr-salon-lite' ),
		'id'            => 'footer-3',
		'description'   => esc_html__( 'Add footer widgets here.', 'tr-salon-lite' ),
		'before_widget' => '<div id="%1$s" class="widget %2$s"><div class="footer-content">',
		'after_widget'  => '</div></div>',
		'before_title'  => '<h3>',
		'after_title'   => '</h3>',
	) );
}
add_action( 'widgets_init', 'tr_salon_lite_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function tr_salon_lite_scripts() {

	wp_enqueue_style( 'tr_salon_lite_style', get_stylesheet_uri() );

	//bootstrap-css

	wp_enqueue_style( 'bootstrap', get_template_directory_uri().'/css/bootstrap.css','3.3.6' );

	//font-awesome-css

	wp_enqueue_style( 'font_awesome', get_template_directory_uri().'/css/font-awesome.css','4.6.3' );

	//pe-icon-7-stroke-css

	wp_enqueue_style( 'pe_icon_7_stroke', get_template_directory_uri().'/css/pe-icon-7-stroke.css');

	//tr_salon_lite-stylesheet-css

	wp_enqueue_style( 'tr_salon_lite_stylesheet', get_template_directory_uri().'/css/style.css', array(),'1.0.8' );

	//tr_salon_lite-responsive-css

	wp_enqueue_style( 'tr_salon_lite_responsive', get_template_directory_uri().'/css/responsive.css', array(), 'a.0.1');

	//wp-jquery

	wp_enqueue_script('jquery');

	//bootstrap-js

	wp_enqueue_script( 'bootstrap', get_template_directory_uri() . '/js/bootstrap.js', array(), '3.3.6', true );

	//jquery.scrollUp-js

	wp_enqueue_script( 'jquery.scrollUp_js', get_template_directory_uri() . '/js/jquery.scrollUp.js', array(), true );

	//tr_salon_lite-custom-js

	wp_enqueue_script( 'tr_salon_lite_custom_js', get_template_directory_uri() . '/js/custom.js', array(), true );

	//tr_salon_lite-navigation-js

	wp_enqueue_script( 'tr_salon_lite_navigation_js', get_template_directory_uri() . '/js/navigation.js', array(), '20151215', true );

	//tr_salon_lite-skip-link-focus-fix-js

	wp_enqueue_script( 'tr_salon_lite_skip_link_focus_fix_js', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20151215', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'tr_salon_lite_scripts' );

// For google fonts

function tr_salon_lite_load_fonts(){
	wp_register_style( 'google-fonts','https://fonts.googleapis.com/css?family=Play:400,700|Rubik:300,400,500,700|Charm:400,700');
	wp_enqueue_style('google-fonts');
}
add_action('wp_print_styles', 'tr_salon_lite_load_fonts');


//remove hash link from read more button

function tr_salon_lite_remove_hash_link($link){
	$link = preg_replace('|#more-[0-9]+|','',$link);
	return $link;
}
add_filter('the_content_more_link','tr_salon_lite_remove_hash_link');
	function tr_salon_lite_styling_read_more(){
		$style = '<div class="custom-btn"><a class="btn" href="'.get_permalink().'" role="button">Read Details</a></div>';
		return $style;
	}
add_filter('the_content_more_link','tr_salon_lite_styling_read_more');	

/*
//For user contact add field

function tr_salon_lite_modify_contact_methods($profile_fields) {

	// Add new fields
	$profile_fields['facebook'] = 'Facebook URL';
	$profile_fields['twitter'] = 'Twitter URL';
	$profile_fields['instagram'] = 'Instagram URL';
	$profile_fields['google-plus'] = 'Google Plus URL';
	$profile_fields['pinterest'] = 'Pinterest URL';

	return $profile_fields;
}
add_filter('user_contactmethods', 'tr_salon_lite_modify_contact_methods');
*/
// comment field to bottom

function tr_salon_lite_move_comment_field_to_bottom( $fields ) {
	$comment_field = $fields['comment'];
	unset( $fields['comment'] );
	$fields['comment'] = $comment_field;
	return $fields;
}

add_filter( 'comment_form_fields', 'tr_salon_lite_move_comment_field_to_bottom' );

// customize comment_form_defaults

function tr_salon_lite_comment_form_defaults( $defaults ) {
  $defaults['title_reply'] = __( 'SUBMIT COMMENT HERE', 'tr-salon-lite' );
  $defaults['comment_notes_before'] = __( ' ', 'tr-salon-lite' );
  return $defaults;
}
add_filter( 'comment_form_defaults', 'tr_salon_lite_comment_form_defaults' );


/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
if ( defined( 'JETPACK__VERSION' ) ) {
	require get_template_directory() . '/inc/jetpack.php';
}

/**
 * Load WooCommerce compatibility file.
 */
if ( class_exists( 'WooCommerce' ) ) {
	require get_template_directory() . '/inc/woocommerce.php';
}

/**
 * Add WP Bootstrap Navwalker Class.
 */
require get_template_directory() . '/inc/wp-bootstrap-navwalker.php';

/**
 * Add WP Bootstrap Commentwalker Class.
 */
require get_template_directory() . '/inc/class-wp-bootstrap-comment-walker.php';

/**
 * Add Custom CSS.
 */
require get_template_directory() . '/inc/custom-css.php';

/**
 * Add Breadcrumb.
 */
require get_template_directory() . '/inc/breadcrumb.php';

